@@ -25,7 +25,7 @@ def corr_save_nii(corrs, filename, affine, corr_mask=None, size=[60, 60, 60], ks
         The similarities between behavioral data and fMRI data for searchlight.
         The shape of RDMs is [n_x, n_y, n_z, 2]. n_x, n_y, n_z represent the number of calculation units for searchlight
         along the x, y, z axis and 2 represents a r-value and a p-value.
-    filename : string
+    filename : string. Default is 'rsa_result.nii'.
         The file path+filename for the result .nii file.
         If the filename does not end in ".nii", it will be filled in automatically.
     affine : array or list
@@ -249,7 +249,7 @@ def stats_save_nii(corrs, filename, affine, corr_mask=None, size=[60, 60, 60], k
         The statistical results between behavioral data and fMRI data for searchlight.
         The shape of RDMs is [n_x, n_y, n_z, 2]. n_x, n_y, n_z represent the number of calculation units for searchlight
         along the x, y, z axis and 2 represents a t-value and a p-value.
-    filename : string
+    filename : string. Default is 'rsa_result.nii'.
         The file path+filename for the result .nii file.
         If the filename does not end in ".nii", it will be filled in automatically.
     affine : array or list
@@ -341,16 +341,42 @@ def stats_save_nii(corrs, filename, affine, corr_mask=None, size=[60, 60, 60], k
     # get the p-values
     corrsp = corrs[:, :, :, 1]
 
+    # calculate the number of voxels for correction
+    fadeimg = np.zeros([nx, ny, nz], dtype=np.int)
+    for i in range(n_x):
+        for j in range(n_y):
+            for k in range(n_z):
+                x = i * sx
+                y = j * sy
+                z = k * sz
+
+                # p-values<threshold-p
+                if corrsp[i, j, k] < p:
+
+                    for k1 in range(kx):
+                        for k2 in range(ky):
+                            for k3 in range(kz):
+                                fadeimg[x + k1, y + k2, z + k3] = 1
+
+    n_corrected = 0
+    for i in range(nx):
+        for j in range(ny):
+            for k in range(nz):
+                if fadeimg[i, j, k] == 1:
+                    n_corrected = n_corrected + 1
+
+    print(str(n_corrected)+" voxels corrected")
+
     # do the correction
     if p < 1:
 
         # FDR-correction
         if correct_method == "FDR":
-            corrsp = fdr_correct(corrsp)
+            corrsp = fdr_correct(corrsp, p_threshold=p)
 
         # FWE-correction
         if correct_method == "FWE":
-            corrsp = fwe_correct(corrsp)
+            corrsp = fwe_correct(corrsp, p_threshold=p)
 
     # iterate through all the calculation units again
 
