@@ -152,16 +152,11 @@ def fdr_correct(p, p_threshold):
     index = np.argsort(pcluster)
 
     for l in range(n):
-        pcluster[index[l]] = float(pcluster[index[l]] * n / (l + 0.5))
+        pcluster[index[l]] = float(pcluster[index[l]]*n/(l+1))
 
-    for l in range(n - 1):
+    """for l in range(n - 1):
         if pcluster[index[-l - 1]] < pcluster[index[-l - 2]]:
-            pcluster[index[-l - 2]] = pcluster[index[-l - 1]]
-
-    newpcluster = np.full([n], np.nan)
-
-    for l in range(n):
-        newpcluster[l] = pcluster[index[l]]
+            pcluster[index[-l - 2]] = pcluster[index[-l - 1]]"""
 
     m = 0
 
@@ -170,7 +165,7 @@ def fdr_correct(p, p_threshold):
             for k in range(pz):
 
                 if (math.isnan(p[i, j, k]) == False) and (p[i, j, k] < p_threshold):
-                    fdrp[i, j, k] = newpcluster[m]
+                    fdrp[i, j, k] = pcluster[m]
                     m = m + 1
 
     print("finished FDR correct")
@@ -458,6 +453,85 @@ def datamask(fmri_data, mask_data):
     return newfmri_data
 
 
+' a function for convert data of MNI template to your data template '
+
+def mask_mni_to(mask_mni, filename, size, affine):
+
+    """
+    convert data of MNI template to your data template
+
+    Parameters:
+    -----------
+    mask_mni : string
+        The file path+filename for the mask of MNI template.
+    filename : string. Default is 'newmask.nii'.
+        The file path+filename for the mask for your data template .nii file.
+    size : array or list [nx, ny, nz]
+        The size of the fMRI-img in your experiments.
+    affine : array or list
+        The position information of the fMRI-image array data in a reference space.
+
+    Notes
+    -----
+    A result .nii file of new mask will be generated at the corresponding address of filename.
+    """
+
+    data = nib.load(mask_mni).get_data()
+
+    nx = size[0]
+    ny = size[1]
+    nz = size[2]
+
+    newdata = np.zeros(size, dtype=np.float)
+
+    for i in range(nx):
+        for j in range(ny):
+            for k in range(nz):
+                if data[i, j, k] != 1 or math.isnan(data[i, j, k]) is False:
+                    mx = 90-i+1
+                    my = j-1-126
+                    mz = k-1-72
+                    x = int(round((float(-affine[0, 3]-mx)/3)+int(affine[0, 0]/abs(affine[0, 0]))))
+                    y = int(round((float(my-affine[1, 3])/3)+int(affine[1, 1]/abs(affine[1, 1]))))
+                    z = int(round((float(my-affine[2, 3])/3)+int(affine[2, 2]/abs(affine[2, 2]))))
+                    newdata[i, j, k] = 1
+
+    file = nib.Nifti1Image(newdata, affine)
+
+    if filename == None:
+        filename = "newmask.nii"
+    else:
+        q = ".nii" in filename
+
+        if q == True:
+            filename = filename
+        else:
+            filename = filename+".nii"
+
+    nib.save(file, filename)
+
+
+' a function for project the position of a point in matrix coordinate system to the position in MNI coordinate system '
+
+def position_to_mni(point, affine):
+
+    """
+    project the position in matrix coordinate system to the position in MNI coordinate system
+
+    Parameters:
+    -----------
+    point : list or array
+        The position in matrix coordinate system.
+    affine : array or list
+        The position information of the fMRI-image array data in a reference space.
+
+    Returns:
+    --------
+    newpoint : array
+        The position in MNI coordinate system.
+    """
+
+
 ' a function for permutation test '
 
 def permutation_test(v1, v2, iter=5000):
